@@ -1,8 +1,8 @@
 package Perinci::To::POD::I18N;
 
-use base 'Perinci::To::DocBase::I18N';
+use base 'Perinci::To::PackageBase::I18N';
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 1;
 # ABSTRACT: Project class for Perinci::To::POD
@@ -16,7 +16,7 @@ Perinci::To::POD::I18N - Project class for Perinci::To::POD
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 AUTHOR
 
