@@ -1,10 +1,10 @@
 package Perinci::To::POD::I18N::en;
-use parent qw(Perinci::To::POD::I18N Perinci::To::DocBase::I18N::en);
+use parent qw(Perinci::To::POD::I18N Perinci::To::PackageBase::I18N::en);
 
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -20,7 +20,7 @@ Perinci::To::POD::I18N::en - English translation for Perinci::To::POD
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 AUTHOR
 
